function ssw_getdst, time0, time1, ace=ace  , $
   quiet=quiet, debug=debug
;+
;   Name: ssw_getdst 
;   
;   Purpose: return DST index for user time range
;
;   Input Parameters:
;      time0 - start time
;      time1 - stop time
;
;   Output:
;      function returns utplot ready time series structure of format:
;          {mjd:0L, time:0L, DST:0.d}
;
;   Keyword Parameters:
;      ace - (switch) - if set, read/use ACE data via get_acedata.pro
;
;   Calling Example:
;      dst = ssw_getdst(reltime(days=-30), reltime(/now)) ; last 30 days 
;
;   History:
;      25-Feb-2004 - S.L.Freeland coded using reference:
;         http://sprg.ssl.berkeley.edu:80/dst_index/estimate.html 
;      26-Feb-2004 - NRT Kyoto hooks
;
;   Restrictions:
;      As of today, only KYOTO NRT (so only last 3/4 months of data) 
;      Kyoto NRT access via sockets so requires IDL V >=5.4
;-
common ssw_getssw_kyotoq, clastm, clastm2, clastm3  ; cache
debug=keyword_set(debug)
loud=1-keyword_set(quiet)

if n_params() lt 2 then begin 
   box_message,'IDL> dst=ssw_getdst(starttime, stoptime [,/ACE])
   return,-1
endif

ace=keyword_set(ace)

case 1 of 
   ace: begin 
   endcase
   ssw_deltat(time0,reltime(/now),/day) lt 120: begin 
      box_message,'Using Kyoto NRT dbase'
      if not since_version('5.4') then begin 
         box_message,'Sorry, http access requires IDL version >= 5.4'
         return,-1   ;   unstructured error return....
      endif
      kyototop='http://swdcdb.kugi.kyoto-u.ac.jp/dstdir/dst1/q/' ; nrt queue
      months=str2arr('lastm3,lastm2,lastm,thism')
      delvarx,retval
      for i=0,n_elements(months)-1 do begin 
         chkq=execute('done=n_elements(c'+months(i)+') gt 0')
         murl=kyototop+ 'Dstq' + months(i) + '.html'
         if debug then stop,'chkq'
         if not done then begin
            box_message,'getting> ' + murl
            sock_list,murl,kyolist
            kyolist=strupcase(strtrim(kyolist,2))
            ss0=where(strpos(kyolist,'DAY') eq 0)
            minit='1-'+str_replace(strcompress(kyolist(ss0-3)),' ','-')
            ssl=where(strpos(kyolist,'</CODE>') eq 0)
            kyolist=strarrcompress(kyolist(ss0+1:ssl-1))
            kyolist=str_replace(kyolist,'9999','  99')
            dst=str2cols(kyolist,/unal)
            lastday=str2number(strmid(last_nelem(kyolist),0,2))
            mgrid=timegrid(minit,nsamp=24.*lastday,/hour,out='utc_int')
            dst=reform(reform(dst(1:*,*),n_elements(mgrid),1))
            mretval=add_tag(mgrid,0.0,'dst')
            mretval.dst=dst
            estat=execute('c'+months(i)+'=mretval')  ; data -> cache
         endif else begin 
            if loud then box_message,['Using cached data for url..',murl] 
            estat=execute('mretval=c'+months(i))
         endelse
         if n_elements(retval) eq 0 then retval=temporary(mretval) else $
            retval=concat_struct(retval,temporary(mretval))
         endfor
      ss=sel_timrange(anytim(retval,/int),time0,time1)
      if ss(0) eq - 1 then begin 
         box_message,'No DST available within your time range
         retval=-1
      endif else begin 
         retval=retval(ss)
      endelse
      if debug then stop
      return,retval
    endcase 
   else: begin 
      box_message,'Sorry, not yet implemented, ; use /ACE keyword'
      return,-1
   endcase
endcase

swepam=get_acedata(time0,time1,/SWEPAM)
   mag=get_acedata(time0,time1,/MAG)

if not data_chk(swepam) then begin 
   box_message,'No ACE data for input times, returning...
   return,-1
endif

; constants   per Burton et al. [1975]
a=3.6e-5     ; ring current decay 1/s
b=.20         ; Dst reponse to dynamic pressure nT/sqrt(eV/cm^3)
c=20          ; quiet time current nT
d=1.2e-3     ; response of injection rate to Ey

bspeed=gt_tagval(swepam,/B_SPEED)     ; Bulk speed km/s
pdensity=gt_tagval(swepam,/P_DENSITY) ; p Density p/cc
bz=gt_tagval(mag,/BZ)                 ; Bz component nT

Ey=-(bspeed*bz)                       ; y GSM comp. of interplanetary e-field
Pdyn=(pdensity*bspeed^2.)             ; dynamic pressure 
 
 
Ring_inj=(d*(Ey-0.5)) * (Ey > .5)     ; ie, 0.0 for Ey < .5 mV/m
; ucb mods per Murayam [1982]
d=-1.2e-3   ;
Ring_inj=((d*Pdyn)^1/3)*(Ey-0.5)

dst_ast=-b * sqrt(pdyn) + c

dst=Ring_inj - (a*dst_ast)


stop
return,dst
end

